@@ -11,7 +11,13 @@ config() {
 }
 config etc/lrzip.conf.new
 
+( cd usr/lib ; rm -rf liblrzip.so.0 )
+( cd usr/lib ; ln -sf liblrzip.so.0.0.0 liblrzip.so.0 )
+( cd usr/lib ; rm -rf liblrzip.so )
+( cd usr/lib ; ln -sf liblrzip.so.0.0.0 liblrzip.so )
 ( cd usr/bin ; rm -rf lrzuntar )
 ( cd usr/bin ; ln -sf lrztar lrzuntar )
+( cd usr/bin ; rm -rf lrzcat )
+( cd usr/bin ; ln -sf lrzip lrzcat )
 ( cd usr/bin ; rm -rf lrunzip )
 ( cd usr/bin ; ln -sf lrzip lrunzip )
